@@ -5,7 +5,7 @@ use WebService::GoogleAPI::Client;
 use Data::Dumper qw (Dumper);
 use WebService::GoogleAPI::Client::Discovery;
 
-require Email::Simple;    ## RFC2822 formatted messages
+require Email::Simple;                  ## RFC2822 formatted messages
 use MIME::Base64;
 use utf8;
 use open ':std', ':encoding(UTF-8)';    ## allows to print out utf8 without errors
@@ -99,42 +99,40 @@ my $DEBUG = 001;
 
 ##    BASIC CLIENT CONFIGURATION
 
-if   ( -e './gapi.json' ) { say "auth file exists" }
-else                      { croak( 'I only work if gapi.json is here' ); }
-;    ## prolly better to fail on setup ?
-my $gapi_agent        = WebService::GoogleAPI::Client->new( debug => $DEBUG, gapi_json => './gapi.json' );
+if   (-e './gapi.json') { say "auth file exists" }
+else                    { croak('I only work if gapi.json is here'); }
+;                                                   ## prolly better to fail on setup ?
+my $gapi_agent        = WebService::GoogleAPI::Client->new(debug => $DEBUG, gapi_json => './gapi.json');
 my $aref_token_emails = $gapi_agent->auth_storage->get_token_emails_from_storage;
-my $user              = $aref_token_emails->[0];                                                             ## default to the first user
-$gapi_agent->user( $user );
+my $user              = $aref_token_emails->[0];    ## default to the first user
+$gapi_agent->user($user);
 
 say "Running tests with default user email = $user";
-say 'Root cache folder: ' . $gapi_agent->discovery->chi->root_dir();                                         ## cached content temporary directory
+say 'Root cache folder: ' . $gapi_agent->discovery->chi->root_dir();    ## cached content temporary directory
 say "User Agent Name = " . $gapi_agent->ua->transactor->name();
 
-if ( 1 == 0 )
-{
+if (1 == 0) {
   #my $api_spec = $gapi_agent->get_api_discovery_for_api_id('gmail:v1');
   #my $api_spec = $gapi_agent->get_api_discovery_for_api_id('gmail.users.messages.list');
   #my $api_spec = $gapi_agent->get_api_discovery_for_api_id('gmail:v1.users.messages.list');
-  my $api_spec = $gapi_agent->get_api_discovery_for_api_id( 'gmail' );
+  my $api_spec = $gapi_agent->get_api_discovery_for_api_id('gmail');
   ## keys = auth, basePath, baseUrl, batchPath, description, discoveryVersion, documentationLink, etag, icons, id, kind, name, ownerDomain, ownerName, parameters, protocol, resources, revision, rootUrl, schemas, servicePath, title, version
-  say join( ', ', sort keys %{ $api_spec } );
-  foreach my $k ( qw/schemas resources auth / ) { $api_spec->{ $k } = 'removed to simplify'; }    ## SIMPLIFY OUTPUT
+  say join(', ', sort keys %{$api_spec});
+  foreach my $k (qw/schemas resources auth /) { $api_spec->{$k} = 'removed to simplify'; }    ## SIMPLIFY OUTPUT
   say Dumper $api_spec;
 
-  my $meths_by_id = $gapi_agent->methods_available_for_google_api_id( 'gmail' );
-  foreach my $meth ( keys %{ $meths_by_id } )
-  {
+  my $meths_by_id = $gapi_agent->methods_available_for_google_api_id('gmail');
+  foreach my $meth (keys %{$meths_by_id}) {
     say "$meth";
   }
 
   # say $gapi_agent->api_query( api_endpoint_id => 'gmail.users.getProfile')->to_string;
   # say $gapi_agent->api_query( api_endpoint_id => 'gmail.users.messages.list')->to_string;
-  foreach my $meth ( qw/ gmail.users.messages.list gmail:v1.users.messages.list /
-    ) ##  gmail.users.settings.getVacation  gmail.users.settings.getImap gmail.users.settings.filters.list    -- FAILERS - gmail.users.messages.get gmail.users.settings.sendAs.smimeInfo.get gmail.users.threads.get
+  foreach my $meth (qw/ gmail.users.messages.list gmail:v1.users.messages.list /
+      ) ##  gmail.users.settings.getVacation  gmail.users.settings.getImap gmail.users.settings.filters.list    -- FAILERS - gmail.users.messages.get gmail.users.settings.sendAs.smimeInfo.get gmail.users.threads.get
   {
     say "Testing endpoint '$meth' with no additional options";
-    my $r = $gapi_agent->api_query( api_endpoint_id => $meth, options => {} );
+    my $r = $gapi_agent->api_query(api_endpoint_id => $meth, options => {});
     say $r->to_string;
     say $r->body;
   }
@@ -143,13 +141,16 @@ if ( 1 == 0 )
 }
 
 
-if ( 1 == 1 )    ## Simplified use Cases
+if (1 == 1)    ## Simplified use Cases
 {
   say $gapi_agent->api_query(
     api_endpoint_id => 'gmail.users.messages.send',
     options         => {
       raw => encode_base64(
-        Email::Simple->create( header => [To => $user, From => $user, Subject => "Test email from $user",], body => "This is the body of email from $user to $user", )->as_string
+        Email::Simple->create(
+          header => [ To => $user, From => $user, Subject => "Test email from $user", ],
+          body   => "This is the body of email from $user to $user",
+        )->as_string
       ),
     },
   )->to_string;    ##
@@ -174,7 +175,7 @@ if ( 1 == 1 )    ## Simplified use Cases
 
 #croak('croak exiting early because DEBUG set') if $DEBUG;
 ## Comment out / Uncomment to enable/disable test the Gmail API functions
-send_email_to_self_using_client( $gapi_agent );
+send_email_to_self_using_client($gapi_agent);
 
 #review_emails_from_last_month_using_agent( $gapi_agent );
 
@@ -196,28 +197,24 @@ REFERENCES:
 =cut
 
 #######################################################
-sub review_emails_from_last_month_using_agent
-{
-  my ( $gapi ) = @_;
-  my $ret      = [];                   ##
-  my $cl       = $gapi->api_query( {
+sub review_emails_from_last_month_using_agent {
+  my ($gapi) = @_;
+  my $ret    = [];                  ##
+  my $cl     = $gapi->api_query({
     httpMethod => 'get',
     path       => "https://www.googleapis.com/gmail/v1/users/me/messages?q=newer_than:1d;to:$user",
 
-  } );
-  if ( $cl->code eq '200' )            ## Mojo::Message::Response
+  });
+  if ($cl->code eq '200')           ## Mojo::Message::Response
   {
     say $cl->to_string;
-    say "resultSizeEstimate = " . $cl->json->{ resultSizeEstimate };
-    foreach my $msg ( @{ $cl->json->{ messages } } )
-    {
+    say "resultSizeEstimate = " . $cl->json->{resultSizeEstimate};
+    foreach my $msg (@{ $cl->json->{messages} }) {
       # print qq{$msg->{id} :: $msg->{threadId}\n};
       ## GET THE MESSAGE CONTENT
-      push @$ret, get_email_content_from_id_using_agent( $msg->{ id }, $gapi );
+      push @$ret, get_email_content_from_id_using_agent($msg->{id}, $gapi);
     }
-  }
-  else
-  {
+  } else {
     croak Dumper $cl;
   }
   return $ret;
@@ -237,68 +234,65 @@ TODO: extract the attachments
 =cut
 
 #######################################################
-sub get_email_content_from_id_using_agent
-{
-  my ( $id, $gapi ) = @_;
+sub get_email_content_from_id_using_agent {
+  my ($id, $gapi) = @_;
 
-  my $retval = { id => $id, Subject => undef, From => undef, 'Delivered-To' => undef, snippet => undef, decoded_parts_by_mimetype => { 'text/html' => [] } };
+  my $retval = {
+    id                        => $id,
+    Subject                   => undef,
+    From                      => undef,
+    'Delivered-To'            => undef,
+    snippet                   => undef,
+    decoded_parts_by_mimetype => { 'text/html' => [] }
+  };
 
-  my $cl = $gapi->api_query( { httpMethod => 'get', path => 'https://www.googleapis.com/gmail/v1/users/me/messages/' . $id, } );
+  my $cl = $gapi->api_query(
+    { httpMethod => 'get', path => 'https://www.googleapis.com/gmail/v1/users/me/messages/' . $id, });
   ## TODO - what is the simplified version ?
   #   my $cl = $gapi->api_query( api_endpoint_id => 'gmail.users.messages' , options => { id => $id } )
 
 
-  if ( $cl->code eq '200' )    ## Mojo::Message::Response
+  if ($cl->code eq '200')    ## Mojo::Message::Response
   {
     #say $cl->to_string;
-    my $boundary = '';         ## get boundary to use as glue between multiparts - haven't finished this - more testing required
-    my $headers  = {};         ## payload provides as an array - wrapping into a hash for interested header names
-    foreach my $header ( @{ $cl->json->{ payload }{ headers } } )
-    {
+    my $boundary = ''; ## get boundary to use as glue between multiparts - haven't finished this - more testing required
+    my $headers  = {}; ## payload provides as an array - wrapping into a hash for interested header names
+    foreach my $header (@{ $cl->json->{payload}{headers} }) {
 
       #print qq{$header->{name}\n};
-      if ( $header->{ name } eq 'Content-Type' )
-      {
+      if ($header->{name} eq 'Content-Type') {
 
-        if ( $header->{ value } =~ /multipart\/alternative; boundary="(.*?)"/mx )
-        {
+        if ($header->{value} =~ /multipart\/alternative; boundary="(.*?)"/mx) {
           #print "Got $header->{value} with $1\n";
           $boundary = $1;
         }
-      }
-      elsif ( $header->{ name } =~ /Subject|From|Delivered-To/mx )
-      {
-        $headers->{ $header->{ name } } = $header->{ value };
+      } elsif ($header->{name} =~ /Subject|From|Delivered-To/mx) {
+        $headers->{ $header->{name} } = $header->{value};
         print "$header->{ name }  = $header->{ value }\n";
       }
     }
-    print $cl->json->{ snippet } . "\n";    # if $DEBUG;
+    print $cl->json->{snippet} . "\n";    # if $DEBUG;
     print Dumper $headers if $DEBUG;
 
     ## process each of the email MIME multiparts
     ## TODO: connect togeteher the multi-part components for attachments etc - some debugging info prints are included to guide this
-    foreach my $p ( @{ $cl->json->{ payload }{ parts } } )
-    {
-      if ( defined $p->{ body }{ data } and defined $boundary )
-      {
-        print "\n --- match found in raw body data ----\n" if $p->{ body }{ data } =~ /$boundary/mx;
+    foreach my $p (@{ $cl->json->{payload}{parts} }) {
+      if (defined $p->{body}{data} and defined $boundary) {
+        print "\n --- match found in raw body data ----\n" if $p->{body}{data} =~ /$boundary/mx;
         ## A GOOGLE SPECIFIC HACK REQUIRED AS PER https://stackoverflow.com/questions/24745006/gmail-api-parse-message-content-base64-decoding-with-javascript
-        $p->{ body }{ data } =~ s/-/+/xsmg;
-        $p->{ body }{ data } =~ s/_/\//xsmg;
-        print "\n --- match found after subs ----\n" if $p->{ body }{ data } =~ /$boundary/mx;
-        my $decoded_part = decode_base64( $p->{ body }{ data } );
+        $p->{body}{data}                                                 =~ s/-/+/xsmg;
+        $p->{body}{data}                                                 =~ s/_/\//xsmg;
+        print "\n --- match found after subs ----\n" if $p->{body}{data} =~ /$boundary/mx;
+        my $decoded_part = decode_base64($p->{body}{data});
         print "\n --- match found after decoding ----\n" if $decoded_part =~ /$boundary/mx;
 
-        if ( $p->{ mimeType } =~ /text/m )
-        {
+        if ($p->{mimeType} =~ /text/m) {
 
           #print $decoded_part if $DEBUG;
         }
       }
     }
-  }
-  else
-  {
+  } else {
     croak Dumper $cl;
   }
 
@@ -319,20 +313,19 @@ TODO:
 =cut
 
 #######################################################
-sub send_email_to_self_using_client
-{
-  my ( $gapi ) = @_;
-  my $cl = $gapi->api_query( {
-    httpMethod => 'post',                                                                                                                ## method as key should also work fine
+sub send_email_to_self_using_client {
+  my ($gapi) = @_;
+  my $cl = $gapi->api_query({
+    httpMethod => 'post',                                                         ## method as key should also work fine
     path       => 'https://www.googleapis.com/gmail/v1/users/me/messages/send',
-    options    => { raw => construct_base64_email( $user, "Test email from $user", "This is the body of email from $user to $user" ) }
-  } );
-  if ( $cl->code eq '200' )                                                                                                              ## Mojo::Message::Response
+    options    => {
+      raw => construct_base64_email($user, "Test email from $user", "This is the body of email from $user to $user")
+    }
+  });
+  if ($cl->code eq '200')    ## Mojo::Message::Response
   {
     say $cl->to_string;
-  }
-  else
-  {
+  } else {
     croak Dumper $cl;
   }
   return $cl;
@@ -340,12 +333,11 @@ sub send_email_to_self_using_client
 #######################################################
 
 #######################################################
-sub construct_base64_email
-{
-  my ( $address, $subject, $body ) = @_;
+sub construct_base64_email {
+  my ($address, $subject, $body) = @_;
 
-  my $email = Email::Simple->create( header => [To => $user, From => $user, Subject => $subject,], body => $body, );
-  return encode_base64( $email->as_string );
+  my $email = Email::Simple->create(header => [ To => $user, From => $user, Subject => $subject, ], body => $body,);
+  return encode_base64($email->as_string);
 }
 #######################################################
 
