@@ -3,7 +3,7 @@ use 5.14.0;
 
 package WebService::GoogleAPI::Client;
 
-our $VERSION = '0.26';    # VERSION
+our $VERSION = '0.27';    # VERSION
 
 use Data::Dump qw/pp/;
 use Moo;
@@ -18,8 +18,6 @@ use Mojo::Util;
 #TODO- batch requests. The only thing necessary is to send  a
 #multipart request as I wrote in that e-mail.
 #
-#TODO- implement auth for service accounts.
-#
 #TODO- allow using promises instead of just calling. Also allow
 #      for full access to the tx instead of assuming it's always
 #      returning the res. Perhaps mix in something that delegates the
@@ -31,13 +29,11 @@ use Mojo::Util;
 
 
 has 'debug' => (is => 'rw', default => 0, lazy => 1);
-has 'ua'    => (
+has 'ua' => (
   handles => [qw/do_autorefresh auth_storage get_access_token scopes user/],
   is      => 'ro',
-  default =>
-    sub { WebService::GoogleAPI::Client::UserAgent->new(debug => shift->debug) }
-  ,
-  lazy => 1,
+  default => sub { WebService::GoogleAPI::Client::UserAgent->new(debug => shift->debug) },
+  lazy    => 1,
 );
 
 sub get_scopes_as_array {
@@ -56,9 +52,9 @@ has 'chi' => (
 has 'discovery' => (
   handles => [
     qw/  discover_all
-      get_method_details
-      get_api_document service_exists
-      methods_available_for_google_api_id list_api_ids  /
+        get_method_details
+        get_api_document service_exists
+        methods_available_for_google_api_id list_api_ids  /
   ],
   is      => 'ro',
   default => sub {
@@ -88,8 +84,7 @@ sub BUILD {
   if ($params->{auth_storage}) {
     $storage = $params->{auth_storage};
   } elsif ($file = $params->{gapi_json}) {
-    $storage =
-      WebService::GoogleAPI::Client::AuthStorage::GapiJSON->new(path => $file);
+    $storage = WebService::GoogleAPI::Client::AuthStorage::GapiJSON->new(path => $file);
   } elsif ($file = $params->{service_account}) {
     $storage = WebService::GoogleAPI::Client::AuthStorage::ServiceAccount->new(
       path   => $file,
@@ -136,32 +131,30 @@ sub api_query {
   carp(pp $params) if $self->debug > 10;
 
   croak "Missing neccessary scopes to access $params->{api_endpoint_id}"
-    unless $self->has_scope_to_access_api_endpoint($params->{api_endpoint_id});
+      unless $self->has_scope_to_access_api_endpoint($params->{api_endpoint_id});
 
   ## used to collect pre-query validation errors - if set we return a response
   #  with 418 I'm a teapot
   my @teapot_errors = ();
   ## pre-query validation if api_id parameter is included
   @teapot_errors = $self->_process_params($params)
-    if (defined $params->{api_endpoint_id});
+      if (defined $params->{api_endpoint_id});
 
   ## either as param or from discovery
   if (not defined $params->{path}) {
     push @teapot_errors, 'path is a required parameter';
     $params->{path} = '';
   }
-  push @teapot_errors,
-    "Path '$params->{path}' includes unfilled variable after processing"
-    if ($params->{path} =~ /\{.+\}/xms);
+  push @teapot_errors, "Path '$params->{path}' includes unfilled variable after processing"
+      if ($params->{path} =~ /\{.+\}/xms);
   ## carp and include in 418 TEAPOT ERROR - response body with @teapot errors
   if (@teapot_errors > 0) {
     carp(join("\n", @teapot_errors)) if $self->debug;
     return Mojo::Message::Response->new(
       content_type => 'text/plain',
       code         => 418,
-      message      =>
-'Teapot Error - Reqeust blocked before submitting to server with pre-query validation errors',
-      body => join("\n", @teapot_errors)
+      message      => 'Teapot Error - Reqeust blocked before submitting to server with pre-query validation errors',
+      body         => join("\n", @teapot_errors)
     );
   } else {
     ## query looks good - send to user agent to execute
@@ -180,18 +173,17 @@ sub _ensure_api_spec_has_defined_fields {
     revision description documentationLink rest/
   ) {
     $api_discovery_struct->{$expected_key} = ''
-      unless defined $api_discovery_struct->{$expected_key};
+        unless defined $api_discovery_struct->{$expected_key};
   }
   $api_discovery_struct->{canonicalName} = $api_discovery_struct->{title}
-    unless defined $api_discovery_struct->{canonicalName};
+      unless defined $api_discovery_struct->{canonicalName};
   return $api_discovery_struct;
 }
 ##################################################
 
 ##################################################
 sub _process_params_for_api_endpoint_and_return_errors {
-  warn
-'_process_params_for_api_endpoint_and_return_errors has been deprecated. Please use _process_params';
+  warn '_process_params_for_api_endpoint_and_return_errors has been deprecated. Please use _process_params';
   _process_params(@_);
 }
 
@@ -200,34 +192,32 @@ sub _process_params {
   my ($self, $params) = @_;
 
   croak('this should never happen - this method is internal only!')
-    unless defined $params->{api_endpoint_id};
+      unless defined $params->{api_endpoint_id};
 
   ## $api_discovery_struct requried for service base URL
-  my $api_discovery_struct = $self->_ensure_api_spec_has_defined_fields(
-    $self->discovery->get_api_document($params->{api_endpoint_id}));
+  my $api_discovery_struct
+      = $self->_ensure_api_spec_has_defined_fields($self->discovery->get_api_document($params->{api_endpoint_id}));
   ## remove trailing '/' from baseUrl
   $api_discovery_struct->{baseUrl} =~ s/\/$//sxmg;
 
   ## if can get discovery data for google api endpoint then continue to perform
   #  detailed checks
-  my $method_discovery_struct =
-    $self->get_method_details($params->{api_endpoint_id});
+  my $method_discovery_struct = $self->get_method_details($params->{api_endpoint_id});
 
   #save away original path so we can know if it's fiddled with
   #later
   $method_discovery_struct->{origPath} = $method_discovery_struct->{path};
 
   ## allow optional user callback pre-processing of method_discovery_struct
-  $method_discovery_struct =
-    &{ $params->{cb_method_discovery_modify} }($method_discovery_struct)
-    if (defined $params->{cb_method_discovery_modify}
-    && ref($params->{cb_method_discovery_modify}) eq 'CODE');
+  $method_discovery_struct = &{ $params->{cb_method_discovery_modify} }($method_discovery_struct)
+      if (defined $params->{cb_method_discovery_modify}
+        && ref($params->{cb_method_discovery_modify}) eq 'CODE');
 
   my @teapot_errors = ();    ## errors are pushed into this as encountered
   $params->{method} = $method_discovery_struct->{httpMethod} || 'GET'
-    if (not defined $params->{method});
+      if (not defined $params->{method});
   push(@teapot_errors,
-"method mismatch - you requested a $params->{method} which conflicts with discovery spec requirement for $method_discovery_struct->{httpMethod}"
+    "method mismatch - you requested a $params->{method} which conflicts with discovery spec requirement for $method_discovery_struct->{httpMethod}"
   ) if ($params->{method} !~ /^$method_discovery_struct->{httpMethod}$/sxim);
 
   ## Set default path iff not set by user - NB - will prepend baseUrl later
@@ -235,18 +225,16 @@ sub _process_params {
   push @teapot_errors, 'path is a required parameter' unless $params->{path};
 
   push @teapot_errors,
-    $self->_interpolate_path_parameters_append_query_params_and_return_errors(
-    $params, $method_discovery_struct);
+      $self->_interpolate_path_parameters_append_query_params_and_return_errors($params, $method_discovery_struct);
 
-  $params->{path} =~ s/^\///sxmg;    ## remove leading '/'  from path
+  $params->{path} =~ s/^\///sxmg;                                            ## remove leading '/'  from path
   $params->{path} = "$api_discovery_struct->{baseUrl}/$params->{path}"
-    unless $params->{path} =~
-    /^$api_discovery_struct->{baseUrl}/ixsmg;    ## prepend baseUrl if required
+      unless $params->{path} =~ /^$api_discovery_struct->{baseUrl}/ixsmg;    ## prepend baseUrl if required
 
   ## if errors - add detail available in the discovery struct for the method and service to aid debugging
   push @teapot_errors,
-qq{ $api_discovery_struct->{title} $api_discovery_struct->{rest} API into $api_discovery_struct->{ownerName} $api_discovery_struct->{canonicalName} $api_discovery_struct->{version} with id $method_discovery_struct->{id} as described by discovery document version $api_discovery_struct->{discoveryVersion} revision $api_discovery_struct->{revision} with documentation at $api_discovery_struct->{documentationLink} \nDescription: $method_discovery_struct->{description}\n}
-    if @teapot_errors;
+      qq{ $api_discovery_struct->{title} $api_discovery_struct->{rest} API into $api_discovery_struct->{ownerName} $api_discovery_struct->{canonicalName} $api_discovery_struct->{version} with id $method_discovery_struct->{id} as described by discovery document version $api_discovery_struct->{discoveryVersion} revision $api_discovery_struct->{revision} with documentation at $api_discovery_struct->{documentationLink} \nDescription: $method_discovery_struct->{description}\n}
+      if @teapot_errors;
 
   return @teapot_errors;
 }
@@ -276,13 +264,9 @@ sub _interpolate_path_parameters_append_query_params_and_return_errors {
 
     #label which param names are from the normal path and from the
     #flat path
-    %path_params =
-      map { $_ => 'plain' } ($discovery_struct->{path} =~ /$param_regex/xg);
+    %path_params = map { $_ => 'plain' } ($discovery_struct->{path} =~ /$param_regex/xg);
     if ($discovery_struct->{flatPath}) {
-      %path_params = (
-        %path_params,
-        map { $_ => 'flat' } ($discovery_struct->{flatPath} =~ /$param_regex/xg)
-      );
+      %path_params = (%path_params, map { $_ => 'flat' } ($discovery_struct->{flatPath} =~ /$param_regex/xg));
     }
   }
 
@@ -290,8 +274,8 @@ sub _interpolate_path_parameters_append_query_params_and_return_errors {
   #switch the path we're dealing with to the flat path if any of
   #the parameters match the flat path
   $params->{path} = $discovery_struct->{flatPath}
-    if grep { $_ eq 'flat' }
-    map { $path_params{ camel $_} || () } keys %{ $params->{options} };
+      if grep { $_ eq 'flat' }
+      map { $path_params{ camel $_} || () } keys %{ $params->{options} };
 
 
   #loop through params given, placing them in the path or query,
@@ -336,7 +320,7 @@ sub _interpolate_path_parameters_append_query_params_and_return_errors {
           $params->{path} =~ s/\{\+$param_name\}/$pattern/x;
           $params->{path} =~ s/$placeholder/$param_value/x;
           push @teapot_errors, "Not enough parameters given for {+$param_name}."
-            if $params->{path} =~ /$placeholder/;
+              if $params->{path} =~ /$placeholder/;
         }
       }
 
@@ -368,8 +352,7 @@ sub _interpolate_path_parameters_append_query_params_and_return_errors {
     my $param_value = $discovery_struct->{parameters}{$param_name}{default};
     $params->{path} =~ s/\{$param_name\}/$param_value/ if $param_value;
   }
-  push @teapot_errors, "Missing a parameter for {$_}."
-    for $params->{path} =~ /$param_regex/g;
+  push @teapot_errors, "Missing a parameter for {$_}." for $params->{path} =~ /$param_regex/g;
 
   #print pp $params;
   #exit;
@@ -392,7 +375,7 @@ sub has_scope_to_access_api_endpoint {
     ## assume permission not granted until we find a matching scope
     my $required_scope_count = 0;
     ## if the final count of scope constraints = 0 then we will assume permission is granted - this has proven necessary for the experimental Google My Business because scopes are not defined in the current discovery data as at 14/10/18
-    for my $method_scope (map { s/\/$//xr } @{ $method_spec->{scopes} }) {
+    for my $method_scope (map {s/\/$//xr} @{ $method_spec->{scopes} }) {
       $required_scope_count++;
       $granted = 1 if defined $configured_scopes_hash{$method_scope};
       last         if $granted;
@@ -426,7 +409,7 @@ WebService::GoogleAPI::Client - Google API Discovery and SDK
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -816,23 +799,13 @@ To check for just one service id, use C<service_exists> instead.
 
 =back
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Veesh Goldman <veesh@cpan.org>
 
-=item *
-
-Peter Scott <localshop@cpan.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017-2021 by Peter Scott and others.
+This software is Copyright (c) 2017-2023 by Veesh Goldman and Others.
 
 This is free software, licensed under:
 
