@@ -2,8 +2,7 @@ use strictures;
 
 package WebService::GoogleAPI::Client::UserAgent;
 
-our $VERSION = '0.26';    # VERSION
-
+our $VERSION = '0.27';    # VERSION
 # ABSTRACT: User Agent wrapper for working with Google APIs
 
 use Moo;
@@ -14,12 +13,13 @@ extends 'Mojo::UserAgent';
 use WebService::GoogleAPI::Client::AuthStorage::GapiJSON;
 use Mojo::UserAgent;
 use Data::Dump qw/pp/;    # for dev debug
+use Data::Printer filters => 'Web';
 
 use Carp qw/croak carp cluck/;
 
 has 'do_autorefresh' => (is => 'rw', default => 1);
 has 'debug'          => (is => 'rw', default => 0);
-has 'auth_storage'   => (
+has 'auth_storage' => (
   is      => 'rw',
   default => sub {
     WebService::GoogleAPI::Client::AuthStorage::GapiJSON->new;
@@ -29,7 +29,7 @@ has 'auth_storage'   => (
   isa     => sub {
     my $role = 'WebService::GoogleAPI::Client::AuthStorage';
     die "auth_storage must implement the $role role to work!"
-      unless $_[0]->does($role);
+        unless $_[0]->does($role);
   },
   lazy => 1
 );
@@ -73,8 +73,7 @@ sub header_with_bearer_auth_token {
   } else {
 
     # TODO - why is this not fatal?
-    carp
-"Can't build Auth header, couldn't get an access token. Is your AuthStorage set up correctly?";
+    carp "Can't build Auth header, couldn't get an access token. Is your AuthStorage set up correctly?";
   }
   return $headers;
 }
@@ -90,18 +89,16 @@ sub build_http_transaction {
   my $http_method   = uc($params->{httpMethod}) || 'GET';    # uppercase ?
   my $optional_data = $params->{options}        || '';
   my $path          = $params->{path}
-    || cluck('path parameter required for build_http_transaction');
+      || cluck('path parameter required for build_http_transaction');
   my $no_auth = $params->{no_auth}
-    || 0;    ## default to including auth header - ie not setting no_auth
+      || 0;    ## default to including auth header - ie not setting no_auth
   my $headers = $params->{headers} || {};
 
   cluck 'Attention! You are using POST, but no payload specified'
-    if (($http_method eq 'POST') && !defined $optional_data);
+      if (($http_method eq 'POST') && !defined $optional_data);
   cluck "build_http_transaction:: $http_method $path " if ($self->debug > 11);
-  cluck
-"$http_method Not a SUPPORTED HTTP method parameter specified to build_http_transaction"
-    . pp $params
-    unless $http_method =~ /^GET|PATH|PUT|POST|PATCH|DELETE$/ixm;
+  cluck "$http_method Not a SUPPORTED HTTP method parameter specified to build_http_transaction" . pp $params
+      unless $http_method =~ /^GET|PATH|PUT|POST|PATCH|DELETE$/ixm;
 
   ## NB - headers not passed if no_auth
   $headers = $self->header_with_bearer_auth_token($headers) unless $no_auth;
@@ -112,23 +109,18 @@ sub build_http_transaction {
       return $self->build_tx($http_method => $path => $headers);
     } else {
       if (ref($optional_data) eq 'HASH') {
-        return $self->build_tx(
-          $http_method => $path => $headers => json => $optional_data);
-      } elsif (
-        ref($optional_data) eq
-        '')    ## am assuming is a post with options containing a binary payload
+        return $self->build_tx($http_method => $path => $headers => json => $optional_data);
+      } elsif (ref($optional_data) eq '')    ## am assuming is a post with options containing a binary payload
       {
-        return $self->build_tx(
-          $http_method => $path => $headers => $optional_data);
+        return $self->build_tx($http_method => $path => $headers => $optional_data);
       }
 
     }
   } else {    ## DELETE or GET
-    return $self->build_tx(
-      $http_method => $path => $headers => form => $optional_data)
-      if ($http_method eq 'GET');
+    return $self->build_tx($http_method => $path => $headers => form => $optional_data)
+        if ($http_method eq 'GET');
     return $self->build_tx($http_method => $path => $headers)
-      if ($http_method eq 'DELETE');
+        if ($http_method eq 'DELETE');
   }
 
   #return undef; ## assert: should never get here
@@ -144,7 +136,7 @@ sub validated_api_query {
   ## assume is a GET for the URI at $params
   if (ref($params) eq '') {
     cluck("transcribing $params to a hashref for validated_api_query")
-      if $self->debug;
+        if $self->debug;
     my $val = $params;
     $params = { path => $val, method => 'get', options => {}, };
   }
@@ -158,11 +150,14 @@ sub validated_api_query {
   #      do this promise-wise
   my $res = $self->start($tx)->res;
   $res->{_token} = $self->get_access_token;
+  if (!$res->code) {
+    cluck "Response has no code! Network error? here's the object:\n" . np $res;
+    return $res;
+  }
 
   if (($res->code == 401) && $self->do_autorefresh) {
-    cluck
-      "Your access token was expired. Attemptimg to update it automatically..."
-      if ($self->debug > 11);
+    cluck "Your access token was expired. Attempting to update it automatically..."
+        if ($self->debug > 11);
 
     $self->auth_storage->refresh_access_token($self);
 
@@ -175,9 +170,9 @@ sub validated_api_query {
     return $res;
   }
   return $res if $res->code == 200;
-  return $res if $res->code == 204;  ## NO CONTENT - INDICATES OK FOR DELETE ETC
-  return $res if $res->code == 400;  ## general failure
-  cluck("unhandled validated_api_query response code " . $res->code);
+  return $res if $res->code == 204;    ## NO CONTENT - INDICATES OK FOR DELETE ETC
+  return $res if $res->code == 400;    ## general failure
+  cluck("unhandled validated_api_query response code; here's the object:\n" . np $res);
   return $res;
 }
 
@@ -195,7 +190,7 @@ WebService::GoogleAPI::Client::UserAgent - User Agent wrapper for working with G
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head2 C<header_with_bearer_auth_token>
 
@@ -242,23 +237,13 @@ See Also: Client->api_query that augments the parameters with some Google API Sp
 
 Returns L<Mojo::Message::Response> object
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Veesh Goldman <veesh@cpan.org>
 
-=item *
-
-Peter Scott <localshop@cpan.org>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017-2021 by Peter Scott and others.
+This software is Copyright (c) 2017-2023 by Veesh Goldman and Others.
 
 This is free software, licensed under:
 
